class Moo:
  def __init__(self):
    print("Moooo! Welcome to my GauShala aka Cowshed!! Mooo ")
    print("Mooooooooooooo! Get some grass and ladoos! ")
    from PIL import Image
    import urllib.request 
    import certifi
    

  def SeeMe(self):
    print("Why not! Have a look ")
    from PIL import Image
    import urllib.request 
    import certifi
    url = "https://i.ibb.co/hgNYffS/mukesh.png"
    im = Image.open(urllib.request.urlopen(url,  cafile=certifi.where()))
    im.show()
    

  def SeeMom(self):
    print("Why not! Have a look ")
    from PIL import Image
    import urllib.request 
    import certifi
    url = "https://i.ibb.co/7JrJf9w/mom.png"
    im = Image.open(urllib.request.urlopen(url, cafile=certifi.where()))
    im.show()

  def SeeDad(self):
    print("Why not! Have a look ")
    from PIL import Image
    import urllib.request 
    import certifi
    url = "https://i.ibb.co/x5FwTQt/dad.png"
    im = Image.open(urllib.request.urlopen(url,  cafile=certifi.where()))
    im.show()

  def SeeFriends(self):
    print("Why not! Have a look ")
    from PIL import Image
    import urllib.request 
    import certifi
    url = "https://i.ibb.co/5LCjZJx/friends.png"
    im = Image.open(urllib.request.urlopen(url,  cafile=certifi.where()))
    im.show()
